.. -*- mode: rst -*-

|license|_ |docs|_ |pypi|_

.. |license| image:: https://img.shields.io/badge/License-MIT-yellow.svg
.. _license: https://opensource.org/licenses/MIT

.. |docs| image:: https://readthedocs.org/projects/miraiml/badge/?version=latest
.. _docs: https://readthedocs.org/projects/miraiml/

.. |pypi| image:: https://badge.fury.io/py/MiraiML.svg
.. _pypi: https://pypi.org/project/MiraiML/

MiraiML
=======

    Mirai: `future` in japanese.

MiraiML is an asynchronous engine for continuous & autonomous machine learning,
built for real-time usage.

Usage
-----

1. Install: ``$ pip install miraiml``
2. Now, inside a Python environment, import the main classes:

>>> from miraiml import HyperSearchSpace, Config, Engine

Some didactic tutorials can be found in the examples_ directory. Or `Read the
Docs`_ for a better understanding of MiraiML.

Development
-----------

1. Download: ``$ git clone https://github.com/arthurpaulino/miraiml.git``
2. Change directory: ``$ cd miraiml``

Now you can install it with ``$ make install`` or ``$ python setup.py install``.

**Note**: Call ``$ make help`` for more info on ``make`` directives.

Contributing
------------

Please, follow the guidelines_ if you want to be part of this project.

.. _examples: https://github.com/arthurpaulino/miraiml/tree/master/examples
.. _Read the Docs: https://miraiml.readthedocs.io/en/latest/
.. _guidelines: https://github.com/arthurpaulino/miraiml/blob/master/CONTRIBUTING.md
